@@ -151,7 +151,9 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -229,6 +231,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -284,6 +287,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
